rusty_mos::process::elf_loader

Struct Elf32Ehdr

#[repr(C)]
pub struct Elf32Ehdr {
Show 14 fields ident: [u8; 16], ftype: u16, _machine: u16, _version: u32, pub entry: u32, phoff: u32, _shoff: u32, _flags: u32, _ehsize: u16, phentsize: u16, phnum: u16, _shentsize: u16, _shnum: u16, _shstrndx: u16,
}
The ELF32 file header structure. The members are defined in the same order as in the actual elf file.

Fields

ident: [u8; 16]

Magic number and other information.

ftype: u16

The object file type.

_machine: u16

The architecture.

_version: u32

The object file version.

entry: u32

The virtual address for the entry point.

phoff: u32

The offset of the program header table from the file’s start.

_shoff: u32

The offset of the section header table from the file’s start.

_flags: u32

The processor-specific flag.

_ehsize: u16

The elf header size (in bytes).

phentsize: u16

The program header table entry size.

phnum: u16

The program header table entry count.

_shentsize: u16

The section header table entry size.

_shnum: u16

The section header table entry count.

_shstrndx: u16

The section header string table index.

Implementations

Source

impl Elf32Ehdr

pub fn from(binary: *const u8, size: usize) -> *const Self

Build the Elf32Ehdr object from the binary.

Return

The raw-pointer of the binary start if the size and the magic number is valid. Otherwise, a null point will be returned.

pub fn foreach(&self, apply: impl Fn(u32))

Walk all the program header entry, use the function apply passed.