#[repr(C)]pub struct Elf32Ehdr {Show 14 fields
ident: [u8; 16],
ftype: u16,
_machine: u16,
_version: u32,
pub entry: u32,
phoff: u32,
_shoff: u32,
_flags: u32,
_ehsize: u16,
phentsize: u16,
phnum: u16,
_shentsize: u16,
_shnum: u16,
_shstrndx: u16,
}Expand description
The ELF32 file header structure. The members are defined in the same order as in the actual elf file.
Fields
ident: [u8; 16]Magic number and other information.
ftype: u16The object file type.
_machine: u16The architecture.
_version: u32The object file version.
entry: u32The virtual address for the entry point.
phoff: u32The offset of the program header table from the file’s start.
_shoff: u32The offset of the section header table from the file’s start.
_flags: u32The processor-specific flag.
_ehsize: u16The elf header size (in bytes).
phentsize: u16The program header table entry size.
phnum: u16The program header table entry count.
_shentsize: u16The section header table entry size.
_shnum: u16The section header table entry count.
_shstrndx: u16The section header string table index.
Implementations